==> classpath-0.10.tar.gz: classpath-0.10/javax/swing/WindowConstants.java <==
/* WindowConstants.java --
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.swing;

/**
 * WindowConstants
 * @author	Andrew Selkirk
 * @version	1.0
 */
public interface WindowConstants {

	//-------------------------------------------------------------
	// Variables --------------------------------------------------
	//-------------------------------------------------------------

	/**
	 * DO_NOTHING_ON_CLOSE
	 */
	int DO_NOTHING_ON_CLOSE = 0;

	/**
	 * HIDE_ON_CLOSE
	 */
	int HIDE_ON_CLOSE = 1;

	/**
	 * DISPOSE_ON_CLOSE
	 */
	int DISPOSE_ON_CLOSE = 2;

	/**
	 * EXIT_ON_CLOSE
	 */
	int EXIT_ON_CLOSE =3;


} // WindowConstants

==> classpath_0.18.orig.tar.gz: classpath-0.18/javax/swing/WindowConstants.java <==
/* WindowConstants.java --
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.swing;

/**
 * Defines some constants that are used in Swing's top-level
 * containers.
 *
 * @author Andrew Selkirk
 */
public interface WindowConstants {

	//-------------------------------------------------------------
	// Variables --------------------------------------------------
	//-------------------------------------------------------------

	/**
	 * DO_NOTHING_ON_CLOSE
	 */
	int DO_NOTHING_ON_CLOSE = 0;

	/**
	 * HIDE_ON_CLOSE
	 */
	int HIDE_ON_CLOSE = 1;

	/**
	 * DISPOSE_ON_CLOSE
	 */
	int DISPOSE_ON_CLOSE = 2;

	/**
	 * EXIT_ON_CLOSE
	 */
	int EXIT_ON_CLOSE =3;


} // WindowConstants
